import 'package:logger/logger.dart' as logger;
import 'package:notice/notice.dart';
import 'package:notice/src/notice_output.dart';
import 'package:notice/src/notice_record.dart';

class LoggerOutputAdapter implements NoticeOutput {
  const LoggerOutputAdapter(this.printer);

  final logger.LogPrinter printer;

  @override
  void onRecord(NoticeRecord record) {
    final level = switch (record.level) {
      NoticeLevel.trace => logger.Level.trace,
      NoticeLevel.debug => logger.Level.debug,
      NoticeLevel.info => logger.Level.info,
      NoticeLevel.warn => logger.Level.warning,
      NoticeLevel.error => logger.Level.error,
      NoticeLevel.fatal => logger.Level.fatal,
      // if this error accours, write fallback
      _ => throw UnimplementedError('Unknown level: ${record.level}'),
    };
    final event = logger.LogEvent(
      level, record.message,
      error: record.error,
      stackTrace: record.stackTrace,
      time: record.timestamp,
    );
    printer.log(event);
  }
}
